@@ -36,7 +36,7 @@ import java.util.Properties;
  * This class contains methods to execute Synergy ccm command line.
  *
  * @author <a href="mailto:julien.henry@capgemini.com">Julien Henry</a>
- * @version $Id: SynergyCCM.java 690997 2008-09-01 15:29:28Z vsiveton $
+ * @version $Id: SynergyCCM.java 891919 2009-12-17 21:29:25Z olamy $
  */
 public class SynergyCCM
 {
@@ -800,6 +800,39 @@ public class SynergyCCM
         return cl;
     }
 
+    /**
+     * Create commandline to start a  remote Synergy session
+     *
+     * @param username
+     * @param password
+     * @param role
+     * @return
+     * @throws ScmException
+     */
+    public static Commandline startRemote( String username, String password, SynergyRole role )
+        throws ScmException
+    {
+        Commandline cl = new Commandline();
+
+        cl.setExecutable( CCM );
+        cl.createArg().setValue( START );
+        cl.createArg().setValue( "-nogui" );
+        cl.createArg().setValue( "-m" ); // Multissesion
+        cl.createArg().setValue( "-q" ); // Quiet (return only CCM_ADDR)
+        cl.createArg().setValue( "-rc" ); //Remote client
+        cl.createArg().setValue( "-n" );
+        cl.createArg().setValue( username );
+        cl.createArg().setValue( "-pw" );
+        cl.createArg().setValue( password );
+        if ( role != null )
+        {
+            cl.createArg().setValue( "-r" );
+            cl.createArg().setValue( role.toString() );
+        }
+
+        return cl;
+    }
+	
     /**
      * Create commandline to get Synergy database delimiter
      *
