@@ -46,7 +46,7 @@ import java.util.Locale;
  * This class contains functional methodsfor Synergy.
  *
  * @author <a href="mailto:julien.henry@capgemini.com">Julien Henry</a>
- * @version $Id: SynergyUtil.java 691832 2008-09-03 23:54:44Z vsiveton $
+ * @version $Id: SynergyUtil.java 894254 2009-12-28 21:55:32Z olamy $
  */
 public class SynergyUtil
 {
@@ -103,10 +103,10 @@ public class SynergyUtil
         }
 
         String query =
-            "owner='" + username + "' and status='working' and type='project' and has_predecessor('" + projectSpec
-                + ":project:1')";
+            "owner='" + username + "' and status='working' and type='project' and has_predecessor('" + projectSpec +"')";
+                //+ ":project:1')"; SCM-261
 
-        Commandline cl = SynergyCCM.query( query, "%displayname", ccmAddr );
+        Commandline cl = SynergyCCM.query( query, "%objectname", ccmAddr );
 
         CommandLineUtils.StringStreamConsumer stderr = new CommandLineUtils.StringStreamConsumer();
         SynergyGetWorkingProjectConsumer stdout = new SynergyGetWorkingProjectConsumer( logger );
@@ -216,7 +216,7 @@ public class SynergyUtil
         SimpleDateFormat toCcmDate = new SimpleDateFormat( "yyyy/MM/dd HH:mm:ss", new Locale( "en", "US" ) );
 
         // Construct the query string
-        String query = "is_task_in_folder_of(is_folder_in_rp_of('" + projectSpec + ":project:1" + "'))";
+        String query = "is_task_in_folder_of(is_folder_in_rp_of('" + projectSpec + "'))";
         if ( startDate != null )
         {
             query = query + "and completion_date>time('" + toCcmDate.format( startDate ) + "')";
@@ -717,7 +717,24 @@ public class SynergyUtil
         CommandLineUtils.StringStreamConsumer stderr = new CommandLineUtils.StringStreamConsumer();
         CommandLineUtils.StringStreamConsumer stdout = new CommandLineUtils.StringStreamConsumer();
 
-        executeSynergyCommand( logger, cl, stderr, stdout, true );
+        //executeSynergyCommand( logger, cl, stderr, stdout, true );
+		
+        int exitCode = executeSynergyCommand( logger, cl, stderr, stdout, false );
+		
+        if ( logger.isDebugEnabled() )
+        {
+            logger.debug( "Synergy : start returns with error code " + exitCode );
+        }		
+		
+        if ( exitCode != 0 ) 
+        {
+            cl = SynergyCCM.startRemote( username, password, role );
+            
+            stderr = new CommandLineUtils.StringStreamConsumer();
+            stdout = new CommandLineUtils.StringStreamConsumer();			
+            
+            executeSynergyCommand( logger, cl, stderr, stdout, true );			
+        }
 
         return stdout.getOutput();
     }
