@@ -393,6 +393,13 @@ public class SynergyCCMTest
         Commandline cl = SynergyCCM.start( "user", "pass", SynergyRole.BUILD_MGR );
         assertCommandLine( "ccm start -nogui -m -q -n user -pw pass -r build_mgr", null, cl );
     }
+	
+    public void testStartRemote()
+        throws ScmException
+    {
+        Commandline cl = SynergyCCM.startRemote( "user", "pass", SynergyRole.BUILD_MGR );
+        assertCommandLine( "ccm start -nogui -m -q -rc -n user -pw pass -r build_mgr", null, cl );
+    }
 
     public void testStop()
         throws Exception
