@@ -19,13 +19,20 @@ package org.apache.maven.scm.provider.git.gitexe.command.checkin;
  * under the License.
  */
 
+import org.apache.maven.scm.provider.git.GitScmTestUtils;
 import org.apache.maven.scm.provider.git.command.checkin.GitCheckInCommandTckTest;
 
 /**
  * @author <a href="mailto:brett@apache.org">Brett Porter</a>
- * @version $Id: GitExeCheckInCommandTckTest.java 645182 2008-04-05 21:58:41Z jvanzyl $
+ * @version $Id: GitExeCheckInCommandTckTest.java 823147 2009-10-08 12:39:23Z struberg $
  */
 public class GitExeCheckInCommandTckTest
     extends GitCheckInCommandTckTest
 {
+        /** {@inheritDoc} */
+        public String getScmUrl()
+            throws Exception
+        {
+            return GitScmTestUtils.getScmUrl( getRepositoryRoot(), "git" );
+        }
 }
