@@ -24,17 +24,11 @@ import org.apache.maven.scm.tck.command.checkin.CheckInCommandTckTest;
 
 /**
  * @author <a href="mailto:struberg@yahoo.de">Mark Struberg</a>
- * @version $Id: GitCheckInCommandTckTest.java 685548 2008-08-13 13:35:49Z vsiveton $
+ * @version $Id: GitCheckInCommandTckTest.java 823147 2009-10-08 12:39:23Z struberg $
  */
-public class GitCheckInCommandTckTest
+public abstract class GitCheckInCommandTckTest
     extends CheckInCommandTckTest
 {
-    /** {@inheritDoc} */
-    public String getScmUrl()
-        throws Exception
-    {
-        return GitScmTestUtils.getScmUrl( getRepositoryRoot() );
-    }
 
     /** {@inheritDoc} */
     public void initRepo()
