@@ -20,6 +20,7 @@ package org.apache.maven.scm.provider;
  */
 
 import org.apache.maven.scm.ScmBranch;
+import org.apache.maven.scm.ScmBranchParameters;
 import org.apache.maven.scm.ScmException;
 import org.apache.maven.scm.ScmFileSet;
 import org.apache.maven.scm.ScmTagParameters;
@@ -55,7 +56,7 @@ import java.util.List;
  * More information about Stubs on <a href="http://martinfowler.com/bliki/TestDouble.html">Martin Fowler's TestDouble</a>
  *
  * @author <a href="mailto:carlos@apache.org">Carlos Sanchez</a>
- * @version $Id: ScmProviderStub.java 754778 2009-03-15 22:26:37Z olamy $
+ * @version $Id: ScmProviderStub.java 892494 2009-12-19 18:40:43Z olamy $
  */
 public class ScmProviderStub
     implements ScmProvider
@@ -348,6 +349,13 @@ public class ScmProviderStub
         return getBranchScmResult();
     }
 
+    /** {@inheritDoc} */
+    public BranchScmResult branch( ScmRepository repository, ScmFileSet fileSet, String branchName, ScmBranchParameters scmBranchParameters )
+        throws ScmException
+    {
+        return getBranchScmResult();
+    }    
+    
     /** {@inheritDoc} */
     public ChangeLogScmResult changeLog( ScmRepository repository, ScmFileSet fileSet, Date startDate, Date endDate,
                                          int numDays, String branch )
